summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDana Powers <dana.powers@gmail.com>2016-02-15 14:23:38 -0800
committerDana Powers <dana.powers@gmail.com>2016-02-15 14:23:38 -0800
commitb2404578d203baecd41eb7b286e8cec10e037a0d (patch)
treeaef1fe67cc99f636940d7561ed1fffb2116f3ad8
parentc0d6273419c84494e8926ff07e1f1612615e63c4 (diff)
downloadkafka-python-b2404578d203baecd41eb7b286e8cec10e037a0d.tar.gz
KAFKA-3044: Re-word consumer.poll behaviour
-rw-r--r--kafka/consumer/group.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/kafka/consumer/group.py b/kafka/consumer/group.py
index efd3bcc..4174b07 100644
--- a/kafka/consumer/group.py
+++ b/kafka/consumer/group.py
@@ -393,9 +393,10 @@ class KafkaConsumer(six.Iterator):
Incompatible with iterator interface -- use one or the other, not both.
Arguments:
- timeout_ms (int, optional): milliseconds to spend waiting in poll if
- data is not available. If 0, returns immediately with any
- records that are available now. Must not be negative. Default: 0
+ timeout_ms (int, optional): milliseconds spent waiting in poll if
+ data is not available in the buffer. If 0, returns immediately
+ with any records that are available currently in the buffer,
+ else returns empty. Must not be negative. Default: 0
Returns:
dict: topic to list of records since the last fetch for the